@@ -5,7 +5,7 @@ LOSH.mc <- function(x, listw, a = 2, nsim = 99, zero.policy = attr(listw, "zero.
   if (!inherits(listw, "listw")) 
     stop(paste(deparse(substitute(listw)), "is not a listw object"))
   if (is.null(zero.policy)) 
-    zero.policy <- get("zeroPolicy", envir = .spdepOptions)
+    zero.policy <- get.ZeroPolicyOption()
   stopifnot(is.logical(zero.policy))
   if (!is.null(attr(listw$neighbours, "self.included")) && 
       attr(listw$neighbours, "self.included")) 
