@@ -1,7 +1,7 @@
-# Copyright 2004-5 by Roger Bivand 
+# Copyright 2004-2010 by Roger Bivand
 #
 
-choynowski <- function(n, x, row.names=NULL, tol=.Machine$double.eps^0.5) {
+choynowski <- function(n, x, row.names=NULL, tol=.Machine$double.eps^0.5, legacy=FALSE) {
   len <- length(n)
   if (len < 1) stop("non-positive number of observations")
   res <- numeric(len)
@@ -11,7 +11,8 @@ choynowski <- function(n, x, row.names=NULL, tol=.Machine$double.eps^0.5) {
   if (b > 1) stop("sum of cases larger than sum of populations at risk")
   E <- x*b
   type <- (n < E)
-  for (i in 1:len) {
+  if (legacy) {
+   for (i in 1:len) {
     if(type[i]) {
       for (j in 0:n[i]) {
         xx <- (E[i]^j*exp(-E[i])) / gamma(j + 1)
@@ -26,6 +27,9 @@ choynowski <- function(n, x, row.names=NULL, tol=.Machine$double.eps^0.5) {
         x <- x + 1
       }
     }
+   }
+  } else {
+    res <- ifelse(type, ppois(n, E), 1 - ppois(n-1, E))
   }
   if (is.null(row.names)) 
     res <- data.frame(pmap=res, type=type)
