@@ -1,8 +1,8 @@
-# Copyright 2001-6 by Roger Bivand 
+# Copyright 2001-6, 2025 #175 by Roger Bivand 
 #
 
 
-diffnb <- function(x, y, verbose=NULL) {
+diffnb <- function(x, y, verbose=NULL, legacy=TRUE) {
 	if (!inherits(x, "nb")) stop("not a neighbours list")
 	if (!inherits(y, "nb")) stop("not a neighbours list")
         if (is.null(verbose)) verbose <- get.VerboseOption()
@@ -13,23 +13,35 @@ diffnb <- function(x, y, verbose=NULL) {
 	if (any(attr(x, "region.id") != attr(y, "region.id")))
 		warning("region.id differ; using ids of first list")
 	ids <- attr(x, "region.id")
-	res <- vector(mode="list", length=n)
-	for (i in 1:n) {
-		xi <- x[[i]]
-		yi <- y[[i]]
-		xt <- xi %in% yi
-		yt <- yi %in% xi
-		if (!(all(xt) && all(yt))) {
-			res[[i]] <- as.integer(sort(unique(c(xi[which(!xt)],
-				yi[which(!yt)]))))
-			if(verbose && (res[[i]] != 0))
+	if (requireNamespace("spatialreg", quietly=TRUE) && !legacy) {
+		Bx <- as(nb2listw(x, style="B", zero.policy=TRUE), 
+			"CsparseMatrix")
+		By <- as(nb2listw(y, style="B", zero.policy=TRUE), 
+			"CsparseMatrix")
+                B <- Bx != By
+                res <- mat2listw(B, style="B", zero.policy=TRUE)$neighbours
+	} else {
+		res <- vector(mode="list", length=n)
+		for (i in 1:n) {
+			xi <- setdiff(x[[i]], 0L)
+			yi <- setdiff(y[[i]], 0L)
+#			xt <- xi %in% yi
+#			yt <- yi %in% xi
+#			if (!(all(xt) && all(yt))) {
+#				res[[i]] <- as.integer(sort(unique(c(xi[which(!xt)],
+#					yi[which(!yt)]))))
+                        xy <- setdiff(xi, yi)
+                        yx <- setdiff(yi, xi)
+			res[[i]] <- as.integer(sort(unique(union(xy, yx))))
+			if (length(res[[i]]) == 0L) res[[i]] <- 0L
+			if(verbose && all(res[[i]] != 0))
 				cat("Neighbour difference for region id:",
 				ids[i], "in relation to id:", ids[res[[i]]], "\n")
-		} else res[[i]] <- 0L
+		}
 	}
-	class(res) <- "nb"
 	attr(res, "region.id") <- attr(x, "region.id")
 	attr(res, "call") <- match.call()
+	class(res) <- "nb"
 	res <- sym.attr.nb(res)
         NE <- n + sum(card(res))
         if (get.SubgraphOption() && get.SubgraphCeiling() > NE) {
