@@ -5,7 +5,7 @@
 is.symmetric.nb <- function(nb, verbose=NULL, force=FALSE)
 {
 	if(!inherits(nb, "nb")) stop("Not neighbours list")
-        if (is.null(verbose)) verbose <- get("verbose", envir = .spdepOptions)
+        if (is.null(verbose)) verbose <- get.VerboseOption()
         stopifnot(is.logical(verbose))
 	nbsym <- attr(nb, "sym")
 	if(!is.null(nbsym)) res <- nbsym
@@ -72,6 +72,19 @@ is.selfneighbour <- function(nb) {
     res <- sapply(seq(along=nb), function(i) i %in% nb[[i]]) 
 }
 
+remove.self <- function(nb) {
+  
+  if (is.null(attr(nb, "self.included")))  stop("Self not included. Cannot remove.")
+  
+  for (i in 1:length(nb)) {
+    nb[[i]] <- nb[[i]][-which(nb[[i]] == i)]
+  }
+  
+  attr(nb, "self.included") <- NULL
+  
+  return(nb)
+}
+
 # Copyright 2001-7 by Nicholas Lewin-Koh and Roger Bivand
 
 old.make.sym.nb <- function(nb){
@@ -142,9 +155,13 @@ aggregate.nb <- function(x, IDs, remove.self=TRUE, ...) {
             if (length(nb_short[[i]]) < 1L) nb_short[[i]] <- 0L
         }
     }
+# RSB fix 180620
+    nb_short[sapply(nb_short, length) == 0L] <- 0L
     attr(nb_short, "region.id") <- out_reg.ids
     class(nb_short) <- "nb"
+    if (any(card(nb_short) == 0L)) nb_short <- subset(nb_short, card(nb_short) > 0L)
     nb_short <- sym.attr.nb(nb_short)
     nb_short
 }
 
+
